# Humidity and Temperature sensor RHT01

This repository contains all CAD files needed for making a Veles RHT01 wired sensor, part of a family of [Veles Smart Household](#veles-smart-household) sensors.

## Basic properties

### Measured values

* Temperature
* Relative humidity
* Light intensity

### Connectivity

* RS-485 with Modbus

### Power requirements

* Input voltage: 5 - 30 V DC

## Where to get these sensors?

We hope to be able to be to offer you these sensors in one way or another (fully assembled or some kits with PCBs and components). In the meantime, you can build one yourselves! You will need a bit of experience with PCB ordering, soldering, and flashing the firmware on STM32. Don't worry though, none of these require deep expertise. Also a 3D printer will come in handy, if you want some of those pretty enclosures.

## Project files

* [Hardware](PCB)
    * Schematic and PCB ([KiCAD](https://www.kicad.org/) project) in [`PCB/rht_wired_sensor.kicad_pro`](PCB/rht_wired_sensor.kicad_pro)
    * PCB step model in [`PCB/Project_Outputs/3D_Model/rht_wired_sensor.step`](PCB/Project_Outputs/3D_Model/rht_wired_sensor.step)
    * Gerbers (PCB manufacturing) of panelized version: [`PCB/Test_Panel/GERBERS/`](PCB/Test_Panel/GERBERS/)
    * Schematic exported as PDF in [`PCB/Project_Outputs/Schematic/rht_wired_sensor.pdf`](PCB/Project_Outputs/Schematic/rht_wired_sensor.pdf)
    * Interactive HTML BOM file in [`PCB/Project_Outputs/iBOM/rht_wired_sensor_proto_ibom.html`](PCB/Project_Outputs/iBOM/rht_wired_sensor_proto_ibom.html)
* [Firmware](fw)
    * This is a [STM32Cube IDE](https://www.st.com/en/development-tools/stm32cubeide.html) project
    * Uses a number of git submodules - clone this repo with `--recursive` or use `git submodule update --init` to get them
* [Enclosure](Enclosure)
    * [FreeCAD](https://www.freecad.org/) project in [`Enclosure/RHT_Sensor_Enclosure.FCStd`](Enclosure/RHT_Sensor_Enclosure.FCStd) 
    * STL files in [`Enclosure/STLs`](Enclosure/STLs)
        * Printing tested on Prusa Mk2S and Ender 3
* [Documentation](Documentation)
    * Datasheet in [`Documentation/Datasheet/RHT_Wired_Sensor_Datasheet.pdf`](Documentation/Datasheet/RHT_Wired_Sensor_Datasheet.pdf)

## Images

<img src="Documentation/Datasheet/fig/rht_wired_sensor.jpg" alt="Front view of the sensor" width="25%" height="auto"><img src="Documentation/Datasheet/fig/rht01_isometric.png" alt="Front view of the sensor" width="25%" height="auto">

<img src="PCB/Project_Outputs/3D_MODEL/Images/rht_wired_sensor.png" alt="IAQ wired sensor render" width="25%" height="auto"><img src="Documentation/Datasheet/fig/rht01_exploded.png" alt="Front view of the sensor" width="25%" height="auto">

## Veles Smart Household

This sensor is part of Veles Smart Household. Goal of this project is to create open hardware and software platform for measuring various quantities, not only related to indoor air quality:

* temperature
* humidity
* atmospheric pressure
* carbon dioxide (CO2)
* carbon monoxide (CO)
* volatile organic compounds (VOC)
* particulate matter (PM - dust particles)
* light intensity
* soil moisture

... and some more!

Sensors are connected either via RS-485 Modbus or wirelessly to central unit. Wireless sensors are currently in development. Central unit may be any anything that can read from the bus: any computer with RS-485 to USB converter (e.g. Raspberry Pi) or an actual PLC. Readout of the sensor is possible via Modbus: either using your own favourite application or using your Python package.

**We want this to be community effort! Come help us make something great!**

### Other Smart Household repositories

* [IAQ wired sensor](https://gitea.veleslabs.org/veles_labs/iaq_sensor_wired)
* [Python package](https://gitea.veleslabs.org/veles_labs/pyveles) for sensor readout and visualization (work in progress)
    * Can be installed using `pip install veles`

## Further reading 

If you need more data, check out the [datasheet](Documentation/Datasheet/RHT_Wired_Sensor_Datasheet.pdf).
